@@ -185,7 +185,7 @@ def PerformSumOfSquaresCoilCombination(images, takeAbsolute=False):
     return combined
 
 # Images should have shape [svdComponents, coils, z, x, y]
-def PerformWalshCoilCombination(images, verbose=False, kernelSize=5, niter=5, device=None):
+def PerformWalshCoilCombination(images, verbose=False, kernelSize=(5,5,1), niter=5, device=None):
     if(device==None):
         if torch.cuda.is_available():
             device = torch.device("cuda")
